Code coverage report for coa/lib/index.js

# All files / coa/lib index.js

100% Statements 5/5
100% Branches 0/0
100% Functions 0/0
100% Lines 5/5

    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    14
    15
    1x
    1x
    1x
    1x

    1x

     const
        Cmd = require('./cmd'),
        Opt = require('./opt'),
        Arg = require('./arg'),
        shell = require('./shell');

    module.exports = {
        Cmd : Cmd.create,
        Opt : Opt.create,
        Arg : Arg.create,
        classes : { Cmd, Opt, Arg },
        shell,
        require
    };